%define plugins down-root auth-pam
%global support_systemd 1

Name:              openvpn
Version:           2.4.3
Release:           1%{?dist}
Epoch:             5
Summary:           A full-featured SSL VPN solution
Summary(ko):       모든 요소를 지원하는 SSL VPN 솔루션
URL:               http://openvpn.net/
Source0:           https://swupdate.openvpn.org/community/releases/openvpn-%{version}.tar.gz
# Sample 2.0 config files
Source2:           roadwarrior-server.conf
Source3:           roadwarrior-client.conf
Source4:           service-startup-pre
Source5:           service-startup-post
Source6:           service-shutdown-pre
Source7:           service-shutdown-post
Source8:           openvpn.conf
Source9:           openvpn.logrotate
Source10:          openvpn.tmpfiles
# Don't start openvpn by default.
Patch0:            openvpn-annyung-init.patch
Patch1:            openvpn-annyung-pam.patch
Patch2:            openvpn-annyung-builtin_except.patch
License:           GPL
Group:             Applications/Internet
BuildRoot:         %{_tmppath}/%{name}-%{version}-%{release}
BuildRequires:     lzo-devel
BuildRequires:     openssl-devel
BuildRequires:     pam-devel
Requires:          lzo, openssl, pam-devel
# We need /dev/net/tun.
# This will work with RH9+ dev or udev.
#Requires:          dev >= 0:3.3.2-5

# Filter out the perl(Authen::PAM) dependency.
# No perl dependency is really needed at all.
%define __perl_requires sh -c 'cat > /dev/null'

%description
OpenVPN is a robust and highly flexible tunneling application that uses all
of the encryption, authentication, and certification features of the
OpenSSL library to securely tunnel IP networks over a single UDP or TCP
port.  It can use the Marcus Franz Xaver Johannes Oberhumer's LZO library
for compression.


%prep
%setup -q -n %{name}-%{version}
%patch0 -p1
#patch1 -p1
%patch2 -p1
sed -i -e 's,%{_datadir}/openvpn/plugin,%{_libdir}/openvpn/plugin,' doc/openvpn.8

# %%doc items shouldn't be executable.
find contrib sample/sample-config-files sample/sample-keys sample/sample-scripts -type f -perm +100 \
    -exec chmod a-x {} \;

%build
#  --enable-password-save  Allow --askpass and --auth-user-pass passwords to be
#                          read from a file
#  --enable-iproute2       Enable support for iproute2

export SYSTEMD_UNIT_DIR="%{_unitdir}"
export TMPFILES_DIR="%{_prefix}/lib/tmpfiles.d"

%configure \
%if %{support_systemd}
	--enable-systemd \
%endif
	--enable-plugins \
	--enable-pam-dlopen \
	--enable-iproute2 \
	--enable-selinux \
	--enable-lzo \
	--enable-x509-alt-username
%{__make}

%install
rm -rf %{buildroot}

%{__make} DESTDIR=%{buildroot} install

%if %{support_systemd}
#install -D -m 0644 distro/systemd/openvpn-client@.service \
#	%{buildroot}%{_unitdir}/openvpn-client@.service
#install -D -m 0644 distro/systemd/openvpn-server@.service \
#	%{buildroot}%{_unitdir}/openvpn@.service
mv  %{buildroot}%{_unitdir}/openvpn-server@.service \
	 %{buildroot}%{_unitdir}/openvpn@.service
%else
install -D -m 0755 distro/rpm/%{name}.init.d.rhel \
    %{buildroot}%{_initrddir}/%{name}
%endif
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/{server,client,scripts}
install -d -m 0755 %{buildroot}%{_sysconfdir}/logrotate.d

mkdir -p %{buildroot}%{_datadir}/%{name}
cp %{SOURCE2} %{SOURCE3} sample/sample-config-files/
install -m755 %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}/scripts/service-startup-pre
install -m755 %{SOURCE5} %{buildroot}%{_sysconfdir}/%{name}/scripts/service-startup-post
install -m755 %{SOURCE6} %{buildroot}%{_sysconfdir}/%{name}/scripts/service-shutdown-pre
install -m755 %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name}/scripts/service-shutdown-post
install -m644 %{SOURCE8} %{buildroot}%{_sysconfdir}/%{name}/server/main.conf
install -m644 %{SOURCE9} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

mkdir -m 755 -p %{buildroot}%{_var}/run/%{name}
mkdir -m 755 -p %{buildroot}%{_var}/log/%{name}

mkdir -p %{buildroot}%{_docdir}/%{name}-%{version}
mv %{buildroot}%{_docdir}/%{name}/* %{buildroot}%{_docdir}/%{name}-%{version}/
rm -rf %{buildroot}%{_docdir}/%{name}

rm -f %{buildroot}%{_libdir}/%{name}/plugins/*.la

%ifarch ix86
	perl -pi -e 's!/usr/lib64!/usr/lib!g' \
		%{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
%endif

%{__mkdir_p} %{buildroot}%{_sysconfdir}/pki/openvpn/

# tmpfiles.d configuration
mkdir -p $RPM_BUILD_ROOT%{_prefix}/lib/tmpfiles.d
install -m 644 -p %{SOURCE10} %{buildroot}%{_prefix}/lib/tmpfiles.d/openvpn.conf

%clean
rm -rf %{buildroot}

%post
%systemd_post openvpn@main.service

%preun
%systemd_preun openvpn@main.service

%postun
%systemd_postun_with_restart openvpn@main.service

%files
%defattr(-,root,root,0755)
#doc AUTHORS COPYING COPYRIGHT.GPL INSTALL PORTS README
# Add NEWS when it isn't zero-length.
%doc contrib sample/sample-config-files sample/sample-keys sample/sample-scripts
%{_mandir}/man8/%{name}.8*
%{_sbindir}/%{name}
%{_libdir}/%{name}/
%if %{support_systemd}
%{_unitdir}/openvpn@.service
%{_unitdir}/openvpn-client@.service
%else
%{_initrddir}/%{name}
%endif
%{_includedir}/openvpn-plugin.h
%{_includedir}/openvpn-msg.h
%{_prefix}/lib/tmpfiles.d/*.conf
%dir %{_var}/run/%{name}/
%dir %{_var}/log/%{name}/
%dir %{_sysconfdir}/%{name}/
%dir %{_sysconfdir}/%{name}/client
%dir %{_sysconfdir}/%{name}/server
%dir %{_sysconfdir}/%{name}/scripts
%dir %{_sysconfdir}/pki/openvpn
%{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/server/main.conf
%config(noreplace) %{_sysconfdir}/%{name}/scripts/service-startup-pre
%config(noreplace) %{_sysconfdir}/%{name}/scripts/service-startup-post
%config(noreplace) %{_sysconfdir}/%{name}/scripts/service-shutdown-pre
%config(noreplace) %{_sysconfdir}/%{name}/scripts/service-shutdown-post

%changelog
* Sat Jun 24 2017 JoungKyun.Kim <hostmaster@oops.org> 5:2.4.3-1%{?dist}
- update 2.4.3
- security issues
  . CVE-2017-7478 Don't assert out on receiving too-large control packets
  . CVE-2017-7479 Drop packets instead of assert out if packet id rolls over
  . CVE-2017-7522 mbedtls: fix --x509-track post-authentication remote DoS
  . CVE-2017-7521 Fix remote-triggerable memory leaks
  . CVE-2017-7521 Fix potential double-free in --x509-alt-username

* Fri Aug  5 2016 JoungKyun.Kim <hostmaster@oops.org> 5:2.3.11-1%{?dist}
- update 2.3.11

* Tue Apr 12 2016 JoungKyun.Kim <hostmaster@oops.org> 5:2.3.10-2%{?dist}
- fixed missing service-startup-pre-%i
- fixed missing tmpfiles

* Mon Apr 11 2016 JoungKyun.Kim <hostmaster@oops.org> 5:2.3.10-1%{?dist}
- update 2.3.10

* Wed Sep  9 2015 JoungKyun.Kim <hostmaster@oops.org> 5:2.3.8-1%{?dist}
- update 2.3.8
- support systemd

* Mon Jul 22 2013 JoungKyun.Kim <hostmaster@oops.org> 5:2.3.2-1%{?dist}
- update 2.3.2

* Mon Aug 13 2012 JoungKyun.Kim <hostmaster@oops.org> 5:2.2.2-1%{?dist}
- update 2.2.2

* Wed Dec  2 2009 JoungKyun.Kim <hostmaster@oops.org> 5:2.1-0.21.rc22
- update 2.1-rc22

* Mon Jul 27 2009 JoungKyun.Kim <hostmaster@oops.org> 4:2.1-0.20.rc19
- fixed openvpn reload on init script

* Wed Jul 22 2009 JoungKyun.Kim <hostmaster@oops.org> 3:2.1-0.19.rc19
- update 2.1-rc19

* Tue Apr  8 2008 JoungKyun.Kim <hostmaster@oops.org> 2:2.1-0.18.rc7
- update 2.1-rc7

* Sun Mar 25 2007 JoungKyun.Kim <hostmaster@oops.org> 1:2.1-0.17.rc2
- rebuilt on AnNyung
- translate configuration file
- fixed pam patch

* Fri Mar 02 2007 Steven Pritchard <steve@kspei.com> 2.1-0.17.rc2
- Update to 2.1_rc2

* Tue Feb 27 2007 Steven Pritchard <steve@kspei.com> 2.1-0.16.rc1
- Randomize ports for tests to avoid conflicts on the build servers

* Tue Feb 27 2007 Steven Pritchard <steve@kspei.com> 2.1-0.15.rc1
- Update to 2.1_rc1

* Mon Oct 02 2006 Steven Pritchard <steve@kspei.com> 2.1-0.14.beta16
- Update to 2.1_beta16
- Drop Paul's patch (in upstream)

* Tue Sep 12 2006 Steven Pritchard <steve@kspei.com> 2.1-0.13.beta15
- Update to 2.1_beta15
- Add openvpn-2.1_beta15-test-timeout.patch to avoid test hang
  (from Paul Howarth)

* Mon Aug 28 2006 Steven Pritchard <steve@kspei.com> 2.1-0.12.beta14
- Rebuild

* Mon Jul 31 2006 Steven Pritchard <steve@kspei.com> 2.1-0.11.beta14
- Rebuild

* Fri Apr 14 2006 Steven Pritchard <steve@kspei.com> 2.1-0.10.beta14
- Update to 2.1_beta14

* Wed Apr 12 2006 Steven Pritchard <steve@kspei.com> 2.1-0.9.beta13
- Update to 2.1_beta13

* Wed Apr 05 2006 Steven Pritchard <steve@kspei.com> 2.1-0.8.beta12
- Update to 2.1_beta12 (BZ#188050/CVE-2006-1629)

* Tue Feb 21 2006 Steven Pritchard <steve@kspei.com> 2.1-0.7.beta11
- Update to 2.1_beta11

* Tue Feb 14 2006 Steven Pritchard <steve@kspei.com> 2.1-0.6.beta8
- Update to 2.1_beta8

* Wed Jan 04 2006 Steven Pritchard <steve@kspei.com> 2.1-0.5.beta7
- Man page shouldn't be executable (BZ#176953)

* Tue Dec 06 2005 Steven Pritchard <steve@kspei.com> 2.1-0.4.beta7
- Rebuild

* Fri Nov 18 2005 Steven Pritchard <steve@kspei.com> 2.1-0.3.beta7
- Update to 2.1_beta7

* Tue Nov 08 2005 Steven Pritchard <steve@kspei.com> 2.1-0.2.beta6
- Make sample-scripts (etc.) non-executable to avoid some dependencies

* Wed Nov 02 2005 Steven Pritchard <steve@kspei.com> 2.1-0.1.beta6
- Update to 2.1_beta6

* Mon Oct 17 2005 Steven Pritchard <steve@kspei.com> 2.1-0.1.beta4
- Update to 2.1_beta4

* Thu Aug 25 2005 Steven Pritchard <steve@kspei.com> 2.0.2-1
- Update to 2.0.2
- Refine roadwarrior-server.conf a bit

* Mon Aug 22 2005 Steven Pritchard <steve@kspei.com> 2.0.1-1
- Update to 2.0.1

* Mon Jun 27 2005 Steven Pritchard <steve@kspei.com> 2.0-2
- Move the plugin directory to _libdir
- Drop the easy-rsa/Windows directory
- Comment cleanups
- Add "processname" header to init script
- The init script isn't a config file
- Tag contrib, sample-config-files, sample-keys, and sample-scripts as doc
- Create/own pid dir

* Sat Jun 25 2005 Steven Pritchard <steve@kspei.com> 2.0-1
- Update to 2.0 final
- Drop Epoch: 0 and rebuild for Fedora Extras

* Wed Feb 16 2005 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.14.rc13
- Fix/add paths to useradd

* Mon Feb 14 2005 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.13.rc13
- Update to 2.0_rc13
- More spec cleanup (suggestions from Matthias Saou)

* Tue Feb 08 2005 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.12.rc12
- Update to 2.0_rc12
- Small spec cleanups
- Drop perl auto-requirements entirely

* Mon Dec 20 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.11.rc6
- Add down-root and auth-pam plugins
- Add --enable-password-save and --enable-iproute2
- Add crypto and loopback tests (somewhat time-consuming)

* Thu Dec 16 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.10.rc5
- Update to 2.0_rc5
- Change the port to 1194 in the roadwarrior-*.conf samples
- Change openvpn-init.patch to reformat the description in the init script
- Modify the Summary and description (OpenVPN isn't UDP-only)

* Tue Dec 14 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.9.rc1
- Remove the perl(Authen::PAM) dependency

* Thu Dec 09 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.8.rc1
- Update to 2.0_rc1

* Tue Nov 16 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.7.beta17
- Update to 2.0_beta17
- Require dev instead of /dev/net/tun (for udev compatibility)
- Change openvpn-init.patch to match upstream (starts even earlier now)

* Wed Aug 04 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.6.beta10
- Remove unnecessary BuildRequires: kernel-headers

* Tue Aug 03 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.5.beta10
- Update to 2.0_beta10
- Minor fix to configuration example
- Change the init script to start a little earlier and stop much later
  (after netfs) by default
- Remove a lot of unnecessary macro use (install/mkdir/cp)
- Don't create /dev/net/tun, use Requires instead

* Sat Jul 17 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.4.beta7
- Update to 2.0_beta7
- Include gpg signature in source rpm
- Include 2.0-style configuration examples
- Minor spec cleanup

* Wed Apr 28 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.3.test23
- Add openvpn-init.patch to leave the init script disabled by default

* Wed Apr 28 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.2.test23
- Fix URL and Source0
- Add an openvpn user

* Wed Apr 28 2004 Steven Pritchard <steve@kspei.com> 0:2.0-0.fdr.0.1.test23
- Update to 2.0_test23
- BuildRequires lzo-devel, kernel-headers, openssl-devel
- Lots of spec cleanup

* Sun Feb 23 2003 Matthias Andree <matthias.andree@gmx.de> 1.3.2.14-1
- Have the version number filled in by autoconf.

* Wed Jul 10 2002 James Yonan <jim@yonan.net> 1.3.1-1
- Fixed %preun to only remove service on final uninstall

* Mon Jun 17 2002 bishop clark (LC957) <bishop@platypus.bc.ca> 1.2.2-1
- Added condrestart to openvpn.spec & openvpn.init.

* Wed May 22 2002 James Yonan <jim@yonan.net> 1.2.0-1
- Added mknod for Linux 2.4.

* Wed May 15 2002 Doug Keller <dsk@voidstar.dyndns.org> 1.1.1.16-2
- Added init scripts
- Added conf file support

* Mon May 13 2002 bishop clark (LC957) <bishop@platypus.bc.ca> 1.1.1.14-1
- Added new directories for config examples and such

* Sun May 12 2002 bishop clark (LC957) <bishop@platypus.bc.ca> 1.1.1.13-1
- Updated buildroot directive and cleanup command
- added easy-rsa utilities

* Mon Mar 25 2002 bishop clark (LC957) <bishop@platypus.bc.ca> 1.0-1
- Initial build.
